@@ -2,14 +2,22 @@
 #'
 #' @description Creates a JAGS formula syntax, prepares data input, and
 #' returns modified prior list for further processing in the \code{JAGS_fit}
-#' function
+#' function.
 #'
 #' @param formula formula specifying the right hand side of the assignment (the
-#' left hand side is ignored)
+#' left hand side is ignored). If the formula contains \code{-1}, it will be
+#' automatically converted to include an intercept with a spike(0) prior.
 #' @param parameter name of the parameter to be created with the formula
 #' @param data data.frame containing predictors included in the formula
 #' @param prior_list named list of prior distribution of parameters specified within
-#' the \code{formula}
+#' the \code{formula}. When using \code{-1} in the formula, an "intercept" prior
+#' can be explicitly specified; otherwise, \code{prior("spike", list(0))} is
+#' automatically added.
+#'
+#' @details When a formula with \code{-1} (no intercept) is specified, the
+#' function automatically removes the \code{-1}, adds an intercept back to the
+#' formula, and includes a spike(0) prior for the intercept to ensure equivalent
+#' model behavior while maintaining consistent formula parsing.
 #'
 #' @examples
 #' # simulate data
@@ -22,7 +30,7 @@
 #'   x_fac4 = factor(rep(c("A", "B", "C", "D"), 15), levels = c("A", "B", "C", "D"))
 #' )
 #'
-#' # specify priors
+#' # specify priors with intercept
 #' prior_list <- list(
 #' "intercept"     = prior("normal", list(0, 1)),
 #' "x_cont"        = prior("normal", list(0, .5)),
@@ -32,10 +40,19 @@
 #' )
 #'
 #' # create the formula object
-#' formula <- JAGS_formula(
+#' formula_obj <- JAGS_formula(
 #'   formula = ~ x_cont + x_fac3 * x_fac4,
 #'   parameter = "mu", data = df, prior_list = prior_list)
 #'
+#' # using -1 notation (automatically adds spike(0) intercept)
+#' prior_list_no_intercept <- list(
+#'   "x_fac3" = prior_factor("normal", list(0, 1), contrast = "treatment")
+#' )
+#' formula_no_intercept <- JAGS_formula(
+#'   formula = ~ x_fac3 - 1,
+#'   parameter = "mu", data = df, prior_list = prior_list_no_intercept)
+#' # Equivalent to specifying intercept = prior("spike", list(0))
+#'
 #' @return \code{JAGS_formula} returns a list containing the formula JAGS syntax,
 #' JAGS data object, and modified prior_list.
 #'
@@ -63,6 +80,17 @@ JAGS_formula <- function(formula, parameter, data, prior_list){
   formula <- .remove_expressions(formula)
   formula <- .remove_random_effects(formula)
 
+  # handle -1 (no intercept) formulas: always add intercept back with spike(0) prior
+  no_intercept_specified <- attr(stats::terms(formula), "intercept") == 0
+  if(no_intercept_specified){
+    # remove -1 from formula and add intercept back
+    formula <- .add_intercept_to_formula(formula)
+    # add spike(0) prior for intercept if not already specified
+    if(!"intercept" %in% names(prior_list)){
+      prior_list[["intercept"]] <- prior("spike", list(0))
+    }
+  }
+
   # obtain predictors characteristics factors
   formula_terms    <- stats::terms(formula)
   has_intercept    <- attr(formula_terms, "intercept") == 1
@@ -694,6 +722,25 @@ JAGS_formula <- function(formula, parameter, data, prior_list){
 .remove_grouping_factor <- function(formula){
   return(trimws(sub("\\|.*$", "", formula)))
 }
+.add_intercept_to_formula <- function(formula){
+  # converts formula with -1 (no intercept) back to formula with intercept
+  # by removing the -1 term
+  formula_str <- paste(deparse(formula), collapse = " ")
+  # Remove various forms of -1 or + -1
+  formula_str <- gsub("\\s*\\-\\s*1\\s*", "", formula_str)
+  formula_str <- gsub("\\s*\\+\\s*\\-\\s*1\\s*", "", formula_str)
+
+  # Handle case where formula becomes empty (just "~")
+  if(grepl("^\\s*~\\s*$", formula_str)){
+    formula_str <- "~ 1"
+  }
+
+  # Clean up any double spaces
+  formula_str <- gsub("\\s{2,}", " ", formula_str)
+  formula_str <- trimws(formula_str)
+
+  return(stats::as.formula(formula_str))
+}
 
 #' @title Evaluate JAGS formula using posterior samples
 #'
@@ -1036,25 +1083,56 @@ transform_treatment_samples <- function(samples){
 }
 
 
-#' @title Orthornomal contrast matrix
+#' @title BayesTools Contrast Matrices
 #'
-#' @description Return a matrix of orthornomal contrasts.
-#' Code is based on \code{stanova::contr.bayes} and corresponding to description
-#' by \insertCite{rouder2012default;textual}{BayesTools}
+#' @description BayesTools provides several contrast matrix functions for Bayesian factor analysis.
+#' These functions create different types of contrast matrices that can be used with factor
+#' variables in Bayesian models.
+#'
+#' @details
+#' The package includes the following contrast functions:
+#' \describe{
+#'   \item{\code{contr.orthonormal}}{Return a matrix of orthonormal contrasts.
+#'     Code is based on \code{stanova::contr.bayes} and corresponding to description
+#'     by \insertCite{rouder2012default;textual}{BayesTools}. Returns a matrix with n rows and
+#'     k columns, with k = n - 1 if \code{contrasts = TRUE} and k = n if \code{contrasts = FALSE}.}
+#'   \item{\code{contr.meandif}}{Return a matrix of mean difference contrasts.
+#'     This is an adjustment to the \code{contr.orthonormal} that ascertains that the prior
+#'     distributions on difference between the gran mean and factor level are identical independent
+#'     of the number of factor levels (which does not hold for the orthonormal contrast). Furthermore,
+#'     the contrast is re-scaled so the specified prior distribution exactly corresponds to the prior
+#'     distribution on difference between each factor level and the grand mean -- this is approximately
+#'     twice the scale of \code{contr.orthonormal}. Returns a matrix with n rows and k columns,
+#'     with k = n - 1 if \code{contrasts = TRUE} and k = n if \code{contrasts = FALSE}.}
+#'   \item{\code{contr.independent}}{Return a matrix of independent contrasts -- a level for each term.
+#'     Returns a matrix with n rows and k columns, with k = n if \code{contrasts = TRUE} and k = n
+#'     if \code{contrasts = FALSE}.}
+#' }
 #'
 #' @param n a vector of levels for a factor, or the number of levels
 #' @param contrasts logical indicating whether contrasts should be computed
 #'
 #' @examples
+#' # Orthonormal contrasts
 #' contr.orthonormal(c(1, 2))
 #' contr.orthonormal(c(1, 2, 3))
 #'
+#' # Mean difference contrasts
+#' contr.meandif(c(1, 2))
+#' contr.meandif(c(1, 2, 3))
+#'
+#' # Independent contrasts
+#' contr.independent(c(1, 2))
+#' contr.independent(c(1, 2, 3))
+#'
 #' @references
 #' \insertAllCited{}
 #'
-#' @return A matrix with n rows and k columns, with k = n - 1 if \code{contrasts = TRUE} and k = n
-#' if \code{contrasts = FALSE}.
-#'
+#' @aliases contr.orthonormal contr.meandif contr.independent
+#' @name contr.BayesTools
+NULL
+
+#' @rdname contr.BayesTools
 #' @export
 contr.orthonormal <- function(n, contrasts = TRUE){
   # based on: stanova::contr.bayes
@@ -1080,29 +1158,7 @@ contr.orthonormal <- function(n, contrasts = TRUE){
   return(cont)
 }
 
-#' @title Mean difference contrast matrix
-#'
-#' @description Return a matrix of mean difference contrasts.
-#' This is an adjustment to the \code{contr.orthonormal} that ascertains that the prior
-#' distributions on difference between the gran mean and factor level are identical independent
-#' of the number of factor levels (which does not hold for the orthonormal contrast). Furthermore,
-#' the contrast is re-scaled so the specified prior distribution exactly corresponds to the prior
-#' distribution on difference between each factor level and the grand mean -- this is approximately
-#' twice the scale of \code{contr.orthonormal}.
-#'
-#' @param n a vector of levels for a factor, or the number of levels
-#' @param contrasts logical indicating whether contrasts should be computed
-#'
-#' @examples
-#' contr.meandif(c(1, 2))
-#' contr.meandif(c(1, 2, 3))
-#'
-#' @references
-#' \insertAllCited{}
-#'
-#' @return A matrix with n rows and k columns, with k = n - 1 if \code{contrasts = TRUE} and k = n
-#' if \code{contrasts = FALSE}.
-#'
+#' @rdname contr.BayesTools
 #' @export
 contr.meandif <- function(n, contrasts = TRUE){
 
@@ -1130,23 +1186,7 @@ contr.meandif <- function(n, contrasts = TRUE){
 }
 
 
-#' @title Independent contrast matrix
-#'
-#' @description Return a matrix of independent contrasts -- a level for each term.
-#'
-#' @param n a vector of levels for a factor, or the number of levels
-#' @param contrasts logical indicating whether contrasts should be computed
-#'
-#' @examples
-#' contr.independent(c(1, 2))
-#' contr.independent(c(1, 2, 3))
-#'
-#' @references
-#' \insertAllCited{}
-#'
-#' @return A matrix with n rows and k columns, with k = n if \code{contrasts = TRUE} and k = n
-#' if \code{contrasts = FALSE}.
-#'
+#' @rdname contr.BayesTools
 #' @export
 contr.independent <- function(n, contrasts = TRUE){
 
