@@ -106,15 +106,21 @@ check_real   <- function(x, name, lower = -Inf, upper = Inf, allow_bound = TRUE,
     }
   }
 
+  if(!allow_NA && anyNA(x))
+    stop(paste0(call, "The '", name, "' argument cannot contain NA/NaN values."), call. = FALSE)
+
+  if(check_length != 0 && length(x) != check_length)
+    stop(paste0(call, "The '", name, "' argument must have length '", check_length, "'."), call. = FALSE)
+
   if(!is.numeric(x) | !is.vector(x))
     stop(paste0(call, "The '", name, "' argument must be a numeric vector."), call. = FALSE)
 
   if(!is.infinite(lower)){
     if(!allow_bound){
-      if(any(x <= lower))
+      if(any(x[!is.na(x)] <= lower))
         stop(paste0(call, "The '", name ,"' must be higher than ", lower,"."), call. = FALSE)
     }else{
-      if(any(x < lower))
+      if(any(x[!is.na(x)] < lower))
         stop(paste0(call, "The '", name ,"' must be equal or higher than ", lower,"."), call. = FALSE)
     }
   }
@@ -129,13 +135,6 @@ check_real   <- function(x, name, lower = -Inf, upper = Inf, allow_bound = TRUE,
     }
   }
 
-  if(check_length != 0 && length(x) != check_length)
-    stop(paste0(call, "The '", name, "' argument must have length '", check_length, "'."), call. = FALSE)
-
-
-  if(!allow_NA && anyNA(x))
-    stop(paste0(call, "The '", name, "' argument cannot contain NA/NaN values."), call. = FALSE)
-
   return()
 }
 
@@ -257,6 +256,22 @@ check_list   <- function(x, name, check_length = 0, check_names = NULL, all_obje
   return(model_samples)
 }
 
+# JASP progress bar functions
+.JASP_progress_bar_start <- function(n, label = "", package_source = "jaspBase"){
+  if(isTRUE(eval(expr = parse(text = paste0("require('", package_source, "')")))) && eval(expr = parse(text = paste0(package_source, '::jaspResultsCalledFromJasp()')))){
+    eval(expr = parse(text = paste0(package_source, '::startProgressbar(expectedTicks = n, label = label)')))
+  }else{
+    cat(paste0(label, "(", n , ")\n"))
+  }
+}
+.JASP_progress_bar_tick  <- function(package_source = "jaspBase"){
+  if(isTRUE(eval(expr = parse(text = paste0("require('", package_source, "')")))) && eval(expr = parse(text = paste0(package_source, '::jaspResultsCalledFromJasp()')))){
+    eval(expr = parse(text = paste0(package_source, '::progressbarTick()')))
+  }else{
+    cat(".")
+  }
+}
+
 # depreciate orthonormal
 .depreciate.transform_orthonormal <- function(transform_orthonormal, transform_factors){
 
